@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import Body, FastAPI
 from pydantic import BaseModel, Field
 
@@ -6,9 +8,11 @@ app = FastAPI()
 
 class Item(BaseModel):
     name: str
-    description: str = Field(None, title="The description of the item", max_length=300)
+    description: Optional[str] = Field(
+        None, title="The description of the item", max_length=300
+    )
     price: float = Field(..., gt=0, description="The price must be greater than zero")
-    tax: float = None
+    tax: Optional[float] = None
 
 
 @app.put("/items/{item_id}")
