@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import FastAPI, Path
 from pydantic import BaseModel
 
@@ -6,17 +8,17 @@ app = FastAPI()
 
 class Item(BaseModel):
     name: str
-    description: str = None
+    description: Optional[str] = None
     price: float
-    tax: float = None
+    tax: Optional[float] = None
 
 
 @app.put("/items/{item_id}")
 async def update_item(
     *,
     item_id: int = Path(..., title="The ID of the item to get", ge=0, le=1000),
-    q: str = None,
-    item: Item = None,
+    q: Optional[str] = None,
+    item: Optional[Item] = None,
 ):
     results = {"item_id": item_id}
     if q:
