@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import Body, FastAPI
 from pydantic import BaseModel
 
@@ -6,14 +8,14 @@ app = FastAPI()
 
 class Item(BaseModel):
     name: str
-    description: str = None
+    description: Optional[str] = None
     price: float
-    tax: float = None
+    tax: Optional[float] = None
 
 
 class User(BaseModel):
     username: str
-    full_name: str = None
+    full_name: Optional[str] = None
 
 
 @app.put("/items/{item_id}")
