@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from fastapi import FastAPI
 from fastapi.encoders import jsonable_encoder
@@ -8,9 +8,9 @@ app = FastAPI()
 
 
 class Item(BaseModel):
-    name: str = None
-    description: str = None
-    price: float = None
+    name: Optional[str] = None
+    description: Optional[str] = None
+    price: Optional[float] = None
     tax: float = 10.5
     tags: List[str] = []
 
