@@ -1,8 +1,10 @@
+from typing import Optional
+
 from fastapi import Cookie, FastAPI
 
 app = FastAPI()
 
 
 @app.get("/items/")
-async def read_items(ads_id: str = Cookie(None)):
+async def read_items(ads_id: Optional[str] = Cookie(None)):
     return {"ads_id": ads_id}
