@@ -1,14 +1,16 @@
+from typing import Optional
+
 from fastapi import Cookie, Depends, FastAPI
 
 app = FastAPI()
 
 
-def query_extractor(q: str = None):
+def query_extractor(q: Optional[str] = None):
     return q
 
 
 def query_or_cookie_extractor(
-    q: str = Depends(query_extractor), last_query: str = Cookie(None)
+    q: str = Depends(query_extractor), last_query: Optional[str] = Cookie(None)
 ):
     if not q:
         return last_query
