@@ -1,10 +1,12 @@
+from typing import Optional
+
 from fastapi import Depends, FastAPI
 from fastapi.testclient import TestClient
 
 app = FastAPI()
 
 
-async def common_parameters(q: str = None, skip: int = 0, limit: int = 100):
+async def common_parameters(q: Optional[str] = None, skip: int = 0, limit: int = 100):
     return {"q": q, "skip": skip, "limit": limit}
 
 
@@ -21,7 +23,7 @@ async def read_users(commons: dict = Depends(common_parameters)):
 client = TestClient(app)
 
 
-async def override_dependency(q: str = None):
+async def override_dependency(q: Optional[str] = None):
     return {"q": q, "skip": 5, "limit": 10}
 
 
