@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import FastAPI
 from pydantic import BaseModel, EmailStr
 
@@ -8,20 +10,20 @@ class UserIn(BaseModel):
     username: str
     password: str
     email: EmailStr
-    full_name: str = None
+    full_name: Optional[str] = None
 
 
 class UserOut(BaseModel):
     username: str
     email: EmailStr
-    full_name: str = None
+    full_name: Optional[str] = None
 
 
 class UserInDB(BaseModel):
     username: str
     hashed_password: str
     email: EmailStr
-    full_name: str = None
+    full_name: Optional[str] = None
 
 
 def fake_password_hasher(raw_password: str):
