@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import FastAPI
 from pydantic import BaseModel, EmailStr
 
@@ -7,7 +9,7 @@ app = FastAPI()
 class UserBase(BaseModel):
     username: str
     email: EmailStr
-    full_name: str = None
+    full_name: Optional[str] = None
 
 
 class UserIn(UserBase):
