@@ -1,8 +1,10 @@
+from typing import Optional
+
 from fastapi import FastAPI, Header
 
 app = FastAPI()
 
 
 @app.get("/items/")
-async def read_items(user_agent: str = Header(None)):
+async def read_items(user_agent: Optional[str] = Header(None)):
     return {"User-Agent": user_agent}
