@@ -12,7 +12,7 @@ class ModelName(str, Enum):
 app = FastAPI()
 
 
-@app.get("/model/{model_name}")
+@app.get("/models/{model_name}")
 async def get_model(model_name: ModelName):
     if model_name == ModelName.alexnet:
         return {"model_name": model_name, "message": "Deep Learning FTW!"}
