@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import FastAPI, Path, Query
 
 app = FastAPI()
@@ -6,7 +8,7 @@ app = FastAPI()
 @app.get("/items/{item_id}")
 async def read_items(
     item_id: int = Path(..., title="The ID of the item to get"),
-    q: str = Query(None, alias="item-query"),
+    q: Optional[str] = Query(None, alias="item-query"),
 ):
     results = {"item_id": item_id}
     if q:
