@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import FastAPI, Query
 
 app = FastAPI()
@@ -5,7 +7,7 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    q: str = Query(None, min_length=3, max_length=50, regex="^fixedquery$")
+    q: Optional[str] = Query(None, min_length=3, max_length=50, regex="^fixedquery$")
 ):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
