@@ -1,10 +1,12 @@
+from typing import Optional
+
 from fastapi import FastAPI, Query
 
 app = FastAPI()
 
 
 @app.get("/items/")
-async def read_items(q: str = Query(None, alias="item-query")):
+async def read_items(q: Optional[str] = Query(None, alias="item-query")):
     results = {"items": [{"item_id": "Foo"}, {"item_id": "Bar"}]}
     if q:
         results.update({"q": q})
