@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from fastapi import FastAPI, Query
 
@@ -6,6 +6,6 @@ app = FastAPI()
 
 
 @app.get("/items/")
-async def read_items(q: List[str] = Query(None)):
+async def read_items(q: Optional[List[str]] = Query(None)):
     query_items = {"q": q}
     return query_items
