@@ -4,6 +4,6 @@ app = FastAPI()
 
 
 @app.get("/items/")
-async def read_items(q: list = Query(None)):
+async def read_items(q: list = Query([])):
     query_items = {"q": q}
     return query_items
