@@ -4,5 +4,5 @@ app = FastAPI()
 
 
 @app.post("/login/")
-async def login(*, username: str = Form(...), password: str = Form(...)):
+async def login(username: str = Form(...), password: str = Form(...)):
     return {"username": username}
