@@ -1,3 +1,5 @@
+from typing import Optional
+
 from fastapi import FastAPI
 from pydantic import BaseModel, Field
 
@@ -6,9 +8,9 @@ app = FastAPI()
 
 class Item(BaseModel):
     name: str = Field(..., example="Foo")
-    description: str = Field(None, example="A very nice Item")
+    description: Optional[str] = Field(None, example="A very nice Item")
     price: float = Field(..., example=35.4)
-    tax: float = Field(None, example=3.2)
+    tax: Optional[float] = Field(None, example=3.2)
 
 
 @app.put("/items/{item_id}")
