@@ -1,11 +1,11 @@
-from typing import List
+from typing import List, Optional
 
 from pydantic import BaseModel
 
 
 class ItemBase(BaseModel):
     title: str
-    description: str = None
+    description: Optional[str] = None
 
 
 class ItemCreate(ItemBase):
