@@ -3,10 +3,8 @@ from base64 import b64decode
 from typing import Optional
 
 from fastapi.exceptions import HTTPException
-from fastapi.openapi.models import (
-    HTTPBase as HTTPBaseModel,
-    HTTPBearer as HTTPBearerModel,
-)
+from fastapi.openapi.models import HTTPBase as HTTPBaseModel
+from fastapi.openapi.models import HTTPBearer as HTTPBearerModel
 from fastapi.security.base import SecurityBase
 from fastapi.security.utils import get_authorization_scheme_param
 from pydantic import BaseModel
@@ -26,7 +24,7 @@ class HTTPAuthorizationCredentials(BaseModel):
 
 class HTTPBase(SecurityBase):
     def __init__(
-        self, *, scheme: str, scheme_name: str = None, auto_error: bool = True
+        self, *, scheme: str, scheme_name: Optional[str] = None, auto_error: bool = True
     ):
         self.model = HTTPBaseModel(scheme=scheme)
         self.scheme_name = scheme_name or self.__class__.__name__
@@ -49,7 +47,11 @@ class HTTPBase(SecurityBase):
 
 class HTTPBasic(HTTPBase):
     def __init__(
-        self, *, scheme_name: str = None, realm: str = None, auto_error: bool = True
+        self,
+        *,
+        scheme_name: Optional[str] = None,
+        realm: Optional[str] = None,
+        auto_error: bool = True,
     ):
         self.model = HTTPBaseModel(scheme="basic")
         self.scheme_name = scheme_name or self.__class__.__name__
@@ -84,7 +86,7 @@ class HTTPBasic(HTTPBase):
         except (ValueError, UnicodeDecodeError, binascii.Error):
             raise invalid_user_credentials_exc
         username, separator, password = data.partition(":")
-        if not (separator):
+        if not separator:
             raise invalid_user_credentials_exc
         return HTTPBasicCredentials(username=username, password=password)
 
@@ -93,8 +95,8 @@ class HTTPBearer(HTTPBase):
     def __init__(
         self,
         *,
-        bearerFormat: str = None,
-        scheme_name: str = None,
+        bearerFormat: Optional[str] = None,
+        scheme_name: Optional[str] = None,
         auto_error: bool = True,
     ):
         self.model = HTTPBearerModel(bearerFormat=bearerFormat)
@@ -125,7 +127,7 @@ class HTTPBearer(HTTPBase):
 
 
 class HTTPDigest(HTTPBase):
-    def __init__(self, *, scheme_name: str = None, auto_error: bool = True):
+    def __init__(self, *, scheme_name: Optional[str] = None, auto_error: bool = True):
         self.model = HTTPBaseModel(scheme="digest")
         self.scheme_name = scheme_name or self.__class__.__name__
         self.auto_error = auto_error
