@@ -5,6 +5,6 @@ set -x
 
 bash ./scripts/lint.sh
 # Check README.md is up to date
-diff --brief docs/en/docs/index.md README.md
+python ./scripts/docs.py verify-readme
 export PYTHONPATH=./docs_src
 pytest --cov=fastapi --cov=tests --cov=docs/src --cov-report=term-missing --cov-report=xml tests ${@}
