@@ -168,7 +168,7 @@ def get_query_type_optional(query: Optional[int] = None):
 
 
 @app.get("/query/int/default")
-def get_query_type_optional(query: int = 10):
+def get_query_type_int_default(query: int = 10):
     return f"foo bar {query}"
 
 
