@@ -42,11 +42,11 @@ client = TestClient(app)
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_path_operation():
     response = client.get("/items/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"id": "foo"}
