@@ -41,28 +41,28 @@ client = TestClient(app)
 def test_normal_counter():
     counter_holder["counter"] = 0
     response = client.get("/counter/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"counter": 1}
     response = client.get("/counter/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"counter": 2}
 
 
 def test_sub_counter():
     counter_holder["counter"] = 0
     response = client.get("/sub-counter/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"counter": 1, "subcounter": 1}
     response = client.get("/sub-counter/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"counter": 2, "subcounter": 2}
 
 
 def test_sub_counter_no_cache():
     counter_holder["counter"] = 0
     response = client.get("/sub-counter-no-cache/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"counter": 2, "subcounter": 1}
     response = client.get("/sub-counter-no-cache/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"counter": 4, "subcounter": 3}
