@@ -21,11 +21,11 @@ client = TestClient(app)
 def test_use_empty():
     with client:
         response = client.get("/prefix")
-        assert response.status_code == 200
+        assert response.status_code == 200, response.text
         assert response.json() == ["OK"]
 
         response = client.get("/prefix/")
-        assert response.status_code == 200
+        assert response.status_code == 200, response.text
         assert response.json() == ["OK"]
 
 
