@@ -145,16 +145,16 @@ client = TestClient(app)
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_path_operations():
     response = client.get("/valid1")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     response = client.get("/valid2")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     response = client.get("/valid3")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     response = client.get("/valid4")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
