@@ -40,19 +40,19 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_security_http_digest():
     response = client.get("/users/me", headers={"Authorization": "Digest foobar"})
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"scheme": "Digest", "credentials": "foobar"}
 
 
 def test_security_http_digest_no_credentials():
     response = client.get("/users/me")
-    assert response.status_code == 403
+    assert response.status_code == 403, response.text
     assert response.json() == {"detail": "Not authenticated"}
 
 
@@ -60,5 +60,5 @@ def test_security_http_digest_incorrect_scheme_credentials():
     response = client.get(
         "/users/me", headers={"Authorization": "Other invalidauthorization"}
     )
-    assert response.status_code == 403
+    assert response.status_code == 403, response.text
     assert response.json() == {"detail": "Invalid authentication credentials"}
