@@ -31,12 +31,12 @@ def get_current_user(oauth_header: Optional[str] = Security(reusable_oauth2)):
 
 
 @app.post("/login")
-def read_current_user(form_data: OAuth2PasswordRequestFormStrict = Depends()):
+def login(form_data: OAuth2PasswordRequestFormStrict = Depends()):
     return form_data
 
 
 @app.get("/users/me")
-def read_current_user(current_user: Optional[User] = Depends(get_current_user)):
+def read_users_me(current_user: Optional[User] = Depends(get_current_user)):
     if current_user is None:
         return {"msg": "Create an account first"}
     return current_user
@@ -66,13 +66,13 @@ openapi_schema = {
                         },
                     },
                 },
-                "summary": "Read Current User",
-                "operationId": "read_current_user_login_post",
+                "summary": "Login",
+                "operationId": "login_login_post",
                 "requestBody": {
                     "content": {
                         "application/x-www-form-urlencoded": {
                             "schema": {
-                                "$ref": "#/components/schemas/Body_read_current_user_login_post"
+                                "$ref": "#/components/schemas/Body_login_login_post"
                             }
                         }
                     },
@@ -88,16 +88,16 @@ openapi_schema = {
                         "content": {"application/json": {"schema": {}}},
                     }
                 },
-                "summary": "Read Current User",
-                "operationId": "read_current_user_users_me_get",
+                "summary": "Read Users Me",
+                "operationId": "read_users_me_users_me_get",
                 "security": [{"OAuth2": []}],
             }
         },
     },
     "components": {
         "schemas": {
-            "Body_read_current_user_login_post": {
-                "title": "Body_read_current_user_login_post",
+            "Body_login_login_post": {
+                "title": "Body_login_login_post",
                 "required": ["grant_type", "username", "password"],
                 "type": "object",
                 "properties": {
