@@ -3,7 +3,7 @@ import shutil
 
 from fastapi.testclient import TestClient
 
-from additional_responses.tutorial002 import app
+from docs_src.additional_responses.tutorial002 import app
 
 client = TestClient(app)
 
