@@ -1,6 +1,6 @@
 from fastapi.testclient import TestClient
 
-from additional_status_codes.tutorial001 import app
+from docs_src.additional_status_codes.tutorial001 import app
 
 client = TestClient(app)
 
