@@ -1,6 +1,6 @@
 from fastapi.testclient import TestClient
 
-from advanced_middleware.tutorial001 import app
+from docs_src.advanced_middleware.tutorial001 import app
 
 
 def test_middleware():
