@@ -3,7 +3,7 @@ from pathlib import Path
 
 from fastapi.testclient import TestClient
 
-from background_tasks.tutorial002 import app
+from docs_src.background_tasks.tutorial002 import app
 
 client = TestClient(app)
 
