@@ -1,7 +1,7 @@
 import pytest
 from fastapi.testclient import TestClient
 
-from body_multiple_params.tutorial001 import app
+from docs_src.body_multiple_params.tutorial001 import app
 
 client = TestClient(app)
 
