@@ -1,6 +1,6 @@
 from fastapi.testclient import TestClient
 
-from body_nested_models.tutorial009 import app
+from docs_src.body_nested_models.tutorial009 import app
 
 client = TestClient(app)
 
