@@ -2,7 +2,7 @@ import importlib
 
 from fastapi.testclient import TestClient
 
-from conditional_openapi import tutorial001
+from docs_src.conditional_openapi import tutorial001
 
 openapi_schema = {
     "openapi": "3.0.2",
