@@ -1,7 +1,7 @@
 import pytest
 from fastapi.testclient import TestClient
 
-from cookie_params.tutorial001 import app
+from docs_src.cookie_params.tutorial001 import app
 
 client = TestClient(app)
 
