@@ -1,6 +1,6 @@
 from fastapi.testclient import TestClient
 
-from extending_openapi.tutorial001 import app
+from docs_src.extending_openapi.tutorial001 import app
 
 client = TestClient(app)
 
