@@ -1,6 +1,6 @@
 from fastapi.testclient import TestClient
 
-from response_cookies.tutorial001 import app
+from docs_src.response_cookies.tutorial001 import app
 
 client = TestClient(app)
 
