@@ -1,6 +1,6 @@
 from fastapi.testclient import TestClient
 
-from security.tutorial003 import app
+from docs_src.security.tutorial003 import app
 
 client = TestClient(app)
 
@@ -102,7 +102,7 @@ openapi_schema = {
         "securitySchemes": {
             "OAuth2PasswordBearer": {
                 "type": "oauth2",
-                "flows": {"password": {"scopes": {}, "tokenUrl": "/token"}},
+                "flows": {"password": {"scopes": {}, "tokenUrl": "token"}},
             }
         },
     },
