@@ -3,7 +3,7 @@ from base64 import b64encode
 from fastapi.testclient import TestClient
 from requests.auth import HTTPBasicAuth
 
-from security.tutorial006 import app
+from docs_src.security.tutorial006 import app
 
 client = TestClient(app)
 
